multidim.models.GaussianMixtureClassifier
=========================================

.. currentmodule:: multidim.models

.. autoclass:: GaussianMixtureClassifier

   

      .. autosummary::
         :toctree:
      
         GaussianMixtureClassifier.evaluate
         GaussianMixtureClassifier.fit
         GaussianMixtureClassifier.gausscoords
         GaussianMixtureClassifier.get_params
         GaussianMixtureClassifier.plot
         GaussianMixtureClassifier.predict
         GaussianMixtureClassifier.runit
         GaussianMixtureClassifier.score
         GaussianMixtureClassifier.set_params



   

